@@ -8,7 +8,6 @@
 
 #include <stdarg.h>
 #include <stdbool.h>
-#include <stddef.h>
 #include <stdint.h>
 #include <stdio.h>
 
@@ -62,7 +61,7 @@
 
 #ifdef __cplusplus
 extern "C" {
-#  if defined(__GNUC__)
+#  ifdef __GNUC__
 #    pragma GCC diagnostic push
 #    pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #  endif
@@ -366,11 +365,11 @@ typedef enum {
 
 /// A syntactic RDF node
 typedef struct {
-  const uint8_t* SERD_NULLABLE buf;     ///< Value string
-  size_t                       n_bytes; ///< Size in bytes (excluding null)
-  size_t                       n_chars; ///< String length (excluding null)
-  SerdNodeFlags                flags;   ///< Node flags (string properties)
-  SerdType                     type;    ///< Node type
+  const uint8_t* SERD_UNSPECIFIED buf;     ///< Value string
+  size_t                          n_bytes; ///< Size in bytes (excluding null)
+  size_t                          n_chars; ///< String length (excluding null)
+  SerdNodeFlags                   flags;   ///< Node flags (string properties)
+  SerdType                        type;    ///< Node type
 } SerdNode;
 
 static const SerdNode SERD_NODE_NULL = {NULL, 0, 0, 0, SERD_NOTHING};
@@ -812,7 +811,7 @@ serd_reader_read_string(SerdReader* SERD_NONNULL    reader,
 /**
    Skip over bytes in the input until a specific byte is encountered.
 
-   Typically used for recording from errors in a line-based syntax by skipping
+   Typically used for recovering from errors in a line-based syntax by skipping
    ahead to the next newline.
 
    @return #SERD_SUCCESS if the given byte was reached, or #SERD_FAILURE if the
@@ -993,7 +992,7 @@ serd_writer_finish(SerdWriter* SERD_NONNULL writer);
 */
 
 #ifdef __cplusplus
-#  if defined(__GNUC__)
+#  ifdef __GNUC__
 #    pragma GCC diagnostic pop
 #  endif
 } /* extern "C" */
